@@ -8,7 +8,7 @@
 const Rules = require("./_rules")
 
 describe("'special.js'", () => {
-    const config = require("../../../lib/configs/_special")
+    const config = require("../../../lib/configs/_override-special")
 
     it("should be a valid config.", () => {
         Rules.validateConfig(config, "special.js")
